# endersgame ![tests](https://github.com/microprediction/endersgame/actions/workflows/tests.yml/badge.svg)

For detecting small departures from martingality in time-series

### About
See ...

 - Colab [notebooks](https://github.com/microprediction/endersnotebooks) demonstrating `Attacker`
 - Recommended [attacker.md](https://github.com/microprediction/endersgame/blob/main/endersgame/attackers/attacker.md)
 - Attacker [FAQ.md](https://github.com/microprediction/endersgame/blob/main/endersgame/attackers/FAQ.md)
 - The tournament at [CrunchDAO.com](https://www.crunchdao.com) where you can use them to win rewards. 


### Install 
Stable:

     pip install endersgame 

Latest:

     pip install git+https://github.com/microprediction/endersgame.git
 



